# Display Group

Display group commands are used to select a subset of the entities displayed in the viewport.

## Create display groups

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupSession.DisplayGroupSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### DisplayGroup

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroup.DisplayGroup
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplayGroupArray

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupArray.DisplayGroupArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplayGroupInstance

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupInstance.DisplayGroupInstance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplayGroupInstanceRepository

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupInstanceRepository.DisplayGroupInstanceRepository
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Leaf

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.Leaf.Leaf
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromConstraintNames

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromConstraintNames.LeafFromConstraintNames
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromDatums

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromDatums.LeafFromDatums
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromDisplayGroup

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromDisplayGroup.LeafFromDisplayGroup
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromElementLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromElementLabels.LeafFromElementLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromElementSets

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromElementSets.LeafFromElementSets
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromElementVarRange

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromElementVarRange.LeafFromElementVarRange
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromGeometry

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromGeometry.LeafFromGeometry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromInstance

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromInstance.LeafFromInstance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromInstanceElementLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromInstanceElementLabels.LeafFromInstanceElementLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromInstanceNodeLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromInstanceNodeLabels.LeafFromInstanceNodeLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromMeshElementLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromMeshElementLabels.LeafFromMeshElementLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromMeshNodeLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromMeshNodeLabels.LeafFromMeshNodeLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromMeshSurfaceSets

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromMeshSurfaceSets.LeafFromMeshSurfaceSets
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromModelElemLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromModelElemLabels.LeafFromModelElemLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromModelNodeLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromModelNodeLabels.LeafFromModelNodeLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromNodeLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromNodeLabels.LeafFromNodeLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromNodeSets

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromNodeSets.LeafFromNodeSets
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromNodeVarRange

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromNodeVarRange.LeafFromNodeVarRange
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbEdgePick

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbEdgePick.LeafFromOdbEdgePick
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementLayups

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementLayups.LeafFromOdbElementLayups
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementMaterials

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementMaterials.LeafFromOdbElementMaterials
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementPick

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPick.LeafFromOdbElementPick
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementPlies

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPlies.LeafFromOdbElementPlies
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementSections

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementSections.LeafFromOdbElementSections
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbElementTypes

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementTypes.LeafFromOdbElementTypes
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromOdbNodePick

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromOdbNodePick.LeafFromOdbNodePick
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromPartElementLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromPartElementLabels.LeafFromPartElementLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromPartInstance

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromPartInstance.LeafFromPartInstance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromPartNodeLabels

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromPartNodeLabels.LeafFromPartNodeLabels
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromReferencePoint

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromReferencePoint.LeafFromReferencePoint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromSets

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromSets.LeafFromSets
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromSurfaceSets

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceSets.LeafFromSurfaceSets
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LeafFromSurfaceVarRange

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceVarRange.LeafFromSurfaceVarRange
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
